@@ -617,8 +617,14 @@ const LocalDocument = new Lang.Class({
     },
 
     updateTypeDescription: function() {
-        if (this.mimeType)
-            this.typeDescription = Gio.content_type_get_description(this.mimeType);
+        let description = '';
+
+        if (this.collection)
+            description = _("Collection");
+        else if (this.mimeType)
+            description = Gio.content_type_get_description(this.mimeType);
+
+        this.typeDescription = description;
     },
 
     load: function(cancellable, callback) {
@@ -728,6 +734,11 @@ const GoogleDocument = new Lang.Class({
                 }
 
                 let uri = entry.get_thumbnail_uri();
+                if (!uri) {
+                    callback(false);
+                    return;
+                }
+
                 let authorizationDomain = service.get_primary_authorization_domain();
                 let inputStream = new GData.DownloadStream({ service: service,
                                                              authorization_domain: authorizationDomain,
@@ -771,12 +782,12 @@ const GoogleDocument = new Lang.Class({
     updateTypeDescription: function() {
         let description;
 
-        if (this.rdfType.indexOf('nfo#Spreadsheet') != -1)
+        if (this.collection)
+            description = _("Collection");
+        else if (this.rdfType.indexOf('nfo#Spreadsheet') != -1)
             description = _("Spreadsheet");
         else if (this.rdfType.indexOf('nfo#Presentation') != -1)
             description = _("Presentation");
-        else if (this.rdfType.indexOf('nfo#DataContainer') != -1)
-            description = _("Collection");
         else
             description = _("Document");
 
@@ -869,12 +880,12 @@ const SkydriveDocument = new Lang.Class({
     updateTypeDescription: function() {
         let description;
 
-        if (this.rdfType.indexOf('nfo#Spreadsheet') != -1)
+        if (this.collection)
+            description = _("Collection");
+        else if (this.rdfType.indexOf('nfo#Spreadsheet') != -1)
             description = _("Spreadsheet");
         else if (this.rdfType.indexOf('nfo#Presentation') != -1)
             description = _("Presentation");
-        else if (this.rdfType.indexOf('nfo#DataContainer') != -1)
-            description = _("Collection");
         else
             description = _("Document");
 
