@@ -1,5 +1,6 @@
 /*
  * Copyright (c) 2012 Meg Ford
+ * Copyright (c) 2012, 2013 Red Hat, Inc.
  *
  * Gnome Documents is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by the
@@ -22,6 +23,7 @@
 const Gio = imports.gi.Gio;
 const GLib = imports.gi.GLib;
 const Gtk = imports.gi.Gtk;
+const Pango = imports.gi.Pango;
 const _ = imports.gettext.gettext;
 
 const Application = imports.application;
@@ -57,6 +59,7 @@ const PropertiesDialog = new Lang.Class({
                                         title: _("Properties"),
                                         hexpand: true });
         this.widget.add_button(_("Done"), Gtk.ResponseType.OK);
+        this.widget.set_default_response(Gtk.ResponseType.OK);
 
         let grid = new Gtk.Grid ({ orientation: Gtk.Orientation.VERTICAL,
                                    row_homogeneous: true,
@@ -120,7 +123,8 @@ const PropertiesDialog = new Lang.Class({
 
         // Title value
         if (doc instanceof Documents.LocalDocument) {
-            this._titleEntry = new Gtk.Entry({ text: doc.name,
+            this._titleEntry = new Gtk.Entry({ activates_default: true,
+                                               text: doc.name,
                                                editable: true,
                                                hexpand: true,
                                                width_chars: 40,
@@ -168,12 +172,19 @@ const PropertiesDialog = new Lang.Class({
                                                     uri: 'https://skydrive.live.com',
                                                     halign: Gtk.Align.START });
         } else { // local document
-            let sourceLink = Gio.file_new_for_uri(doc.uri).get_parent();
-            let sourcePath = sourceLink.get_path();
+            if (doc.collection) {
+                this._sourceData = new Gtk.Label({ label: doc.sourceName,
+                                                   halign: Gtk.Align.START });
+            } else {
+                let sourceLink = Gio.file_new_for_uri(doc.uri).get_parent();
+                let sourcePath = sourceLink.get_path();
 
-            this._sourceData = new Gtk.LinkButton({ label: sourcePath,
-                                                    uri: sourceLink.get_uri(),
-                                                    halign: Gtk.Align.START });
+                this._sourceData = new Gtk.LinkButton({ label: sourcePath,
+                                                        uri: sourceLink.get_uri(),
+                                                        halign: Gtk.Align.START });
+                let label = this._sourceData.get_child();
+                label.set_ellipsize(Pango.EllipsizeMode.END);
+            }
         }
 
         grid.attach_next_to (this._sourceData, this._source, Gtk.PositionType.RIGHT, 2, 1);
